@@ -1,4 +1,6 @@
 package POE::Component::Client::NSCA;
+$POE::Component::Client::NSCA::VERSION = '0.18';
+#ABSTRACT: a POE Component that implements send_nsca functionality
 
 use strict;
 use warnings;
@@ -6,9 +8,6 @@ use POE qw(Wheel::SocketFactory Filter::Stream Wheel::ReadWrite);
 use Carp;
 use Socket;
 use integer;
-use vars qw($VERSION);
-
-$VERSION = '0.16';
 
 use constant PROGRAM_VERSION => "1.2.0b4-Perl";
 use constant MODIFICATION_DATE => "16-03-2006";
@@ -234,7 +233,7 @@ sub _sock_in {
       timestamp => substr($input, TRANSMITTED_IV_SIZE, SIZEOF_U_INT32_T),
   };
   my $data_packet_string_a = pack('n', NSCA_PACKET_VERSION_3) . "\000\000";
-  my $data_packet_string_b = 
+  my $data_packet_string_b =
 	$init_packet->{timestamp} .
 	pack('n', $self->{message}->{return_code}) .
 	pack(('a'.MAX_HOSTNAME_LENGTH), $self->{message}->{host_name}) .
@@ -441,10 +440,18 @@ sub _encrypt_mcrypt {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Client::NSCA - a POE Component that implements send_nsca functionality
 
+=head1 VERSION
+
+version 0.18
+
 =head1 SYNOPSIS
 
    use strict;
@@ -564,22 +571,12 @@ This is generated by the poco. ARG0 will be a hash reference with the following
   'success', indicates that the check was successfully sent to the NSCA daemon;
   'error', only exists if something went wrong;
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+=head1 PROVENANCE
 
 Based on L<Net::Nsca> by P Kent
 
 Which was originally derived from work by Ethan Galstad.
 
-See the LICENSE file for details.
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams, P Kent and Ethan Galstad.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -590,4 +587,15 @@ L<Mcrypt>
 
 L<http://www.nagios.org/>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams, P Kent and Ethan Galstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
